@@ -24,6 +24,8 @@ from yojenkins.yo_jenkins.jenkins_item_classes import JenkinsItemClasses
 
 logger = logging.getLogger()
 
+CONFIG_DIR_NAME = ".yojenkins"
+
 
 class TextStyle:
     """Text style definitions"""
@@ -1013,3 +1015,52 @@ def run_groovy_script(script_filepath: str, json_return: bool, rest: object,
             return {}, False, 'Failed to parse response to JSON format'
 
     return script_result, True, ''
+
+
+def get_item_action(item_info: dict, class_type: str) -> List[dict]:
+    """Get the item's actions for a specific action class type
+
+    Args:
+        item_info: The item info dictionary (ie. job info, build info, etc.)
+        class_type: The class type of the item
+
+    Returns:
+        List of matched actions for the item
+    """
+    logger.debug(f'Getting actions for item coresponding to class type "{class_type}" ...')
+    actions_info = []
+    for action in item_info['actions']:
+        if action:
+            if action['_class'] == class_type:
+                actions_info.append(action)
+
+    return actions_info
+
+
+def create_new_history_file(file_path: str) -> None:
+    """Create a new blank command history file.
+
+    Args:
+        file_path: Full path to the history file
+
+    Returns:
+        None
+    """
+    try:
+        # Creating configuration directory if it does not exist
+        config_dir_abs_path = os.path.join(Path.home(), CONFIG_DIR_NAME)
+
+        if not os.path.exists(config_dir_abs_path):
+            logger.debug("Configuration directory does not exist. Creating it ...")
+            os.makedirs(config_dir_abs_path)
+
+        if not os.path.exists(file_path):
+            logger.debug(f'Command history file NOT found: "{file_path}"')
+            logger.debug("Creating a new command history file ...")
+        with open(file_path, "w") as open_file:
+            json.dump({}, open_file)
+
+    except (FileNotFoundError, IOError, PermissionError) as error:
+        fail_out(f'Failed to create history file ({file_path}). Exception: {error}')
+    except Exception as error:
+        logger.exception(f"Failed to create new command history file. Exception: {error}")
