@@ -96,7 +96,7 @@ class Auth:
                        token_name: str = '',
                        server_base_url: str = '',
                        username: str = '',
-                       password: str = '') -> str:  # nosec
+                       password: str = '') -> str:
         """Generate a Jenkins server API token with the specified server/username
 
         Args:
@@ -137,7 +137,8 @@ class Auth:
                                                             auth=(username, password),
                                                             new_session=True)
         if not success:
-            fail_out('Failed to generate API token. Crumb issuer failed')
+            fail_out('Failed to generate API token. Crumb issuer failed. '
+                     'Check server base URL, username, or password.')
         crumb_value = re.sub(re.compile('<.*?>|Jenkins-Crumb'), '', request_return_text)
         logger.debug(f'Request crumb value: {crumb_value}')
 
@@ -232,15 +233,7 @@ class Auth:
         Returns:
             This is a description of what is returned.
         """
-        # Creating configuration directory if it does not exist
         config_dir_abs_path = os.path.join(Path.home(), CONFIG_DIR_NAME)
-        if not self._detect_config_dir()[0]:
-            logger.debug(f'Creating configuration directory in user home directory: {config_dir_abs_path}')
-            try:
-                os.makedirs(config_dir_abs_path)
-                logger.debug(f'Successfully created configuration directory: {config_dir_abs_path}')
-            except OSError as error:
-                fail_out(f'Failed to create user configuration directory "{config_dir_abs_path}": Exception:{error}')
 
         # Checking if credential config file exists
         file_exists, file_path = self._detect_creds_file()
@@ -252,7 +245,7 @@ class Auth:
             profiles = utility.load_contents_from_local_file("toml", file_path)
             logger.debug(f'Currently listed profile names: {", ".join(list(profiles.keys()))}')
 
-            print2(f'Credentials profile file found in current user home directory: {file_path}')
+            logger.debug(f'Credentials profile file found in current user home directory: {file_path}')
         else:
             creds_file_abs_path = os.path.join(config_dir_abs_path, CREDS_FILE_NAME)
 
@@ -262,8 +255,8 @@ class Auth:
             # Create new profile from scratch
             profiles = {}
 
-            print2(f'Credentials profile file ({CREDS_FILE_NAME}) NOT found in configuration directory')
-            print2(f'Creating a new credentials file: {creds_file_abs_path} ...')
+            logger.debug(f'Credentials profile file NOT found: "{creds_file_abs_path}"')
+            logger.debug(f'Creating a new credentials file ...')
 
         # Check if user passed authentication info file
         if auth_file:
@@ -327,7 +320,8 @@ class Auth:
                 profiles[setup_profile_name] = setup_profile_info
         else:
             # Prompting user for details
-            print2('Please enter the following information to create your first profile entry:')
+            print2('Please enter the following information to create your first profile entry')
+            print2(f'This information will be stored in "{creds_file_abs_path}"')
             print2('')
             profile_name = input(TextStyle.BOLD + TextStyle.YELLOW + '[ OPTIONAL ] Enter PROFILE NAME (default):  ' +
                                  TextStyle.NORMAL)
